==> haskell-input-parsers-0.3.0.2-158.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-input-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 input-parsers
version:              0.3.0.2
visibility:           public
id:                   input-parsers-0.3.0.2-DwvK8OUZWyZ4fkpKiXm2dU
key:                  input-parsers-0.3.0.2-DwvK8OUZWyZ4fkpKiXm2dU
license:              BSD-3-Clause
copyright:            (c) 2020 Mario Blažević
maintainer:           blamario@protonmail.com
author:               Mario Blažević
synopsis:
    Extension of the parsers library with more capability and efficiency

description:
    Extended version of the parsers library, with the additional classes providing more
    capable and efficient methods.

category:             Parsing
abi:                  51210dfe4a371349b9140a27b30a05b4
exposed:              True
exposed-modules:
    Text.Parser.Deterministic Text.Parser.Input
    Text.Parser.Input.Position Text.Parser.Wrapper

hidden-modules:       Text.Parser.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/input-parsers-0.3.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/input-parsers-0.3.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/input-parsers-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-input-parsers
hs-libraries:         HSinput-parsers-0.3.0.2-DwvK8OUZWyZ4fkpKiXm2dU
depends:
    attoparsec-0.14.4-8gkbEkDkw506qTMOo0v2nm base-4.18.2.1
    binary-0.8.9.1 bytestring-0.11.5.3
    monoid-subclasses-1.2.6-7KbTBKsXBlzEyI3ejm9oYQ parsec-3.1.16.1
    parsers-0.12.12-1ZzbvPY4A605Mj7Pb7vKRT text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-input-parsers/html/input-parsers.haddock

haddock-html:         /usr/share/doc/haskell-input-parsers/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-input-parsers-0.3.0.2-159-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-input-parsers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 input-parsers
version:              0.3.0.2
visibility:           public
id:                   input-parsers-0.3.0.2-FZ0S7DcTCCDIfCKHmlg6IQ
key:                  input-parsers-0.3.0.2-FZ0S7DcTCCDIfCKHmlg6IQ
license:              BSD-3-Clause
copyright:            (c) 2020 Mario Blažević
maintainer:           blamario@protonmail.com
author:               Mario Blažević
synopsis:
    Extension of the parsers library with more capability and efficiency

description:
    Extended version of the parsers library, with the additional classes providing more
    capable and efficient methods.

category:             Parsing
abi:                  1231e3d2a02ea859df930847f86ab360
exposed:              True
exposed-modules:
    Text.Parser.Deterministic Text.Parser.Input
    Text.Parser.Input.Position Text.Parser.Wrapper

hidden-modules:       Text.Parser.Internal
import-dirs:          /usr/lib/ghc-9.6.6/site-local/input-parsers-0.3.0.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/input-parsers-0.3.0.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/input-parsers-0.3.0.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-input-parsers
hs-libraries:         HSinput-parsers-0.3.0.2-FZ0S7DcTCCDIfCKHmlg6IQ
depends:
    attoparsec-0.14.4-68EOoedQqwu8mpKj0RmtvE base-4.18.2.1
    binary-0.8.9.1 bytestring-0.11.5.3
    monoid-subclasses-1.2.6-EZJPdYqYzmuKbvx9v3aZNT parsec-3.1.16.1
    parsers-0.12.12-PO1r5WusBRCqoNlSszPjk text-2.0.2
    transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-input-parsers/html/input-parsers.haddock

haddock-html:         /usr/share/doc/haskell-input-parsers/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
